@@ -18,7 +18,7 @@ sub import {
     TCOD::Event->import::into( scalar caller );
 }
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 my $bundle = FFI::Platypus->new( api => 1 );
 $bundle->bundle('TCOD');
@@ -1046,12 +1046,22 @@ package TCOD::Tileset {
     });
 
     $ffi->attach( [ TCOD_tileset_load => 'load_tilesheet' ] => [qw( string int int int int[] )] => 'TCOD_tileset' => sub {
-        my ( $xsub, undef, $path, $cols, $rows, $charmap ) = @_;
+        my ( $xsub, undef, %args ) = ( shift, shift );
 
-        Carp::croak "Cannot load tilesheet from $path: no such file"
-            unless -f $path;
+        %args = @_ != 4 ? @_ : (
+            path     => shift,
+            columns  => shift,
+            rows     => shift,
+            charmarp => shift,
+        );
 
-        $xsub->( $path, $cols, $rows, scalar @{ $charmap }, $charmap );
+        Carp::croak "Cannot load tilesheet from $args{path}: no such file"
+            unless -f $args{path};
+
+        $xsub->(
+            @args{qw( path columns rows )},
+            scalar @{ $args{charmap} }, $args{charmap},
+        );
     });
 
     $ffi->attach( [ TCOD_tileset_get_tile_ => 'get_tile' ] => [qw( TCOD_tileset int )] => 'int' => sub {
@@ -1151,6 +1161,8 @@ package TCOD::Context {
             $args{$out} = $ffi->cast( $cast => opaque => $args{$out} ) if $cast;
         }
 
+        $args{sdl_window_flags} //= TCOD::SDL2::WINDOW_RESIZABLE();
+
         my $err = $xsub->( TCOD::ContextParams->new(\%args), \my $ctx );
         Carp::croak TCOD::get_error() if $err < 0;
 
@@ -1215,12 +1227,48 @@ package TCOD::Context {
             TCOD_colorRGBA => opaque => TCOD::ColorRGBA->new( $c->r, $c->g, $c->b, 0xFF ),
         );
 
-        my $err = $xsub->( $self, $args{console}, TCOD::ViewportOptions->new(\%args) );
+        my $err = $xsub->( $self, delete $args{console}, TCOD::ViewportOptions->new(\%args) );
         Carp::croak TCOD::get_error() if $err < 0;
 
         return;
     });
 
+    sub convert_event {
+        my ( $self, $event ) = @_;
+
+        if ( $event->isa('TCOD::Event::Mouse') && !$event->isa('TCOD::Event::MouseWheel') ) {
+            $event->{tilexy} = [ $self->pixel_to_tile( @{ $event->{xy} } ) ];
+        }
+
+        if ( $event->isa('TCOD::Event::MouseMotion') ) {
+            my ( $xx, $yy ) = $self->pixel_to_tile(
+                $event->{xy}[0] - $event->{dxy}[0],
+                $event->{xy}[1] - $event->{dxy}[1],
+            );
+
+            $event->{tiledxy} = [
+                $event->{tilexy}[0] - $xx,
+                $event->{tilexy}[1] - $yy,
+            ];
+        }
+    }
+
+    $ffi->attach( [ screen_pixel_to_tile_i => 'pixel_to_tile' ] => [qw( TCOD_context int* int* )] => 'TCOD_error' => sub {
+        my ( $xsub, $self, $x, $y ) = @_;
+        my ( $xx, $yy ) = ( $x, $y );
+        my $err = $xsub->( $self, \$xx, \$yy );
+        Carp::croak TCOD::get_error() if $err < 0;
+        ( $xx, $yy );
+    });
+
+    $ffi->attach( [ screen_pixel_to_tile_d => 'pixel_to_subtile' ] => [qw( TCOD_context double* double* )] => 'TCOD_error' => sub {
+        my ( $xsub, $self, $x, $y ) = @_;
+        my ( $xx, $yy ) = ( $x, $y );
+        my $err = $xsub->( $self, \$xx, \$yy );
+        Carp::croak TCOD::get_error() if $err < 0;
+        ( $xx, $yy );
+    });
+
     $ffi->mangler( sub { shift } );
     $ffi->attach( [ TCOD_context_delete => 'DESTROY' ] => ['TCOD_context'] => 'void' );
 }
